Selectable item.

The following `width` values are possible:

* `= 0.0`: Use remaining width.
* `> 0.0`: Specific width.

The following `height` values are possible:

* `= 0.0`: Use label height.
* `> 0.0`: Specific height.